diff -up doxygen-1.7.1/src/fortrancode.l.external doxygen-1.7.1/src/fortrancode.l
--- doxygen-1.7.1/src/fortrancode.l.external	2010-11-18 06:28:23.690104123 -0700
+++ doxygen-1.7.1/src/fortrancode.l	2010-11-18 16:58:25.150979615 -0700
@@ -78,8 +78,9 @@ class Scope 
   public:
     QStringList useNames; //!< contains names of used modules
     QDict<void> localVars; //!< contains names of local variables
+    QDict<void> externalFuncs; //!< contains names of external functions
 
-    Scope() : localVars(7, FALSE /*caseSensitive*/) {}
+    Scope() : localVars(7, FALSE /*caseSensitive*/), externalFuncs(7, FALSE /*caseSensitive*/) {}
 };
 
 /*===================================================================*/
@@ -616,7 +617,37 @@ void addUse(QString moduleName) 
 void addLocalVar(QString varName) 
 {
   if (!scopeStack.isEmpty())
-    scopeStack.last()->localVars.insert(varName, (void*)1);
+  {
+    // If not already declared external, save as local variable
+    if (!scopeStack.last()->externalFuncs.find(varName))
+    {
+      scopeStack.last()->localVars.insert(varName, (void*)1);
+      //fprintf(stderr, "Added local variable '%s'\n", (const char *)varName);
+    }
+  }
+}
+
+void addExternalFunc(QString varName) 
+{
+  if (!scopeStack.isEmpty())
+  {
+    // Make sure this is really defined elsewhere
+    if (Doxygen::functionNameSDict->find((const char *)varName))
+    {
+      // Remove from local variables if being declared external now
+      if (scopeStack.last()->localVars.find(varName))
+      {
+        scopeStack.last()->localVars.remove(varName);
+        //fprintf(stderr, "Removed local variable '%s'\n", (const char *)varName);
+      }
+      scopeStack.last()->externalFuncs.insert(varName, (void*)1);
+      //fprintf(stderr, "Added external function '%s'\n", (const char *)varName);
+    }
+    else
+    {
+      //fprintf(stderr, "Refusing to add nonexistant external function '%s'\n", (const char *)varName);
+    }
+  }
 }
 
 //----------------------------------------------------------------------------
@@ -681,6 +712,8 @@ IGNORE (CALL)
 %x DeclContLine
 %x Parameterlist
 %x String
+%x External
+%x ExtContLine
 
 %%
  /*==================================================================*/
@@ -825,6 +858,10 @@ IGNORE (CALL)
                                        }
 <Start>{ATTR_SPEC}		       { 
    					  startFontClass("keywordtype");
+					  if(0 == strcmp(yytext, "external")){
+					    yy_push_state(YY_START);
+					    BEGIN(External);
+					  }
 					  g_code->codify(yytext);
 					  endFontClass();
                                        }
@@ -862,6 +899,25 @@ IGNORE (CALL)
 					  bracketCount = 0;
                                           yy_pop_state();
  					}
+<External>{ID}                          { // external function
+					  g_code->codify(yytext);
+					  if (g_currentMemberDef && g_currentMemberDef->isFunction())
+					    addExternalFunc(yytext);
+					}
+<External>"&"                           { // external continuation line
+                                          yy_push_state(YY_START);
+					  BEGIN(ExtContLine);
+					}
+<ExtContLine>"\n"                       { // external not yet finished
+                                          codifyLines(yytext);
+					  bracketCount = 0;
+                                          yy_pop_state();
+ 				 	}
+<External>"\n"                          { // end external line
+					  codifyLines(yytext);
+					  bracketCount = 0;
+                                          yy_pop_state();
+ 					}
 
  /*-------- subprog calls  -----------------------------------------*/
 
